package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
	"strings"
)

var _ FsTagsModel = (*customFsTagsModel)(nil)

type (
	// FsTagsModel is an interface to be customized, add more methods here,
	// and implement the added methods in customFsTagsModel.
	FsTagsModel interface {
		fsTagsModel
		GetAllByLevel(ctx context.Context, level int) (resp []FsTags, err error)
		GetAllByIds(ctx context.Context, ids []string) (resp []FsTags, err error)
	}

	customFsTagsModel struct {
		*defaultFsTagsModel
	}
)

// NewFsTagsModel returns a model for the database table.
func NewFsTagsModel(conn sqlx.SqlConn) FsTagsModel {
	return &customFsTagsModel{
		defaultFsTagsModel: newFsTagsModel(conn),
	}
}

func (m *defaultFsTagsModel) GetAllByLevel(ctx context.Context, level int) (resp []FsTags, err error) {
	query := fmt.Sprintf("select %s from %s where `level` = ? and `status` = ?", fsTagsRows, m.table)
	err = m.conn.QueryRowsCtx(ctx, &resp, query, level, 1)
	if err != nil {
		return nil, err
	}
	return
}
func (m *defaultFsTagsModel) GetAllByIds(ctx context.Context, ids []string) (resp []FsTags, err error) {
	query := fmt.Sprintf("select %s from %s where `id` in (?) and `status` = ?", fsTagsRows, m.table)
	err = m.conn.QueryRowsCtx(ctx, &resp, query, strings.Join(ids, ","), 1)
	if err != nil {
		return nil, err
	}
	return
}
